<?php $TRANSLATIONS = array(
"Music" => "Música",
"songs" => "músicas",
"albums" => "albuns",
"Add album to playlist" => "Adicionar álbum à lista",
"Play" => "Tocar",
"Pause" => "Pausa",
"Previous" => "Anterior",
"Next" => "Próximo",
"Mute" => "Mudo",
"Unmute" => "Não Mudo",
"Rescan Collection" => "Atualizar a Coleção",
"Artist" => "Artista",
"Album" => "Álbum",
"Title" => "Título"
);
